@@ -22,24 +22,25 @@ class BaseVar:
     """
     Base variable class.
 
-    Derived classes `State` and `Algeb` should be used to build
-    model variables.
+    Derived classes `State` and `Algeb` should be used to build model variables.
 
     Parameters
     ----------
-    name : str, optional
-        Variable name
     info : str, optional
         Descriptive information
     unit : str, optional
         Unit
     tex_name : str
-        LaTeX-formatted variable name. If is None, use `name`
-        instead.
+        LaTeX-formatted variable symbol. If is None, the value of `name` will be
+        used.
     discrete : Discrete
-        Discrete component on which thi variable depends on.
-        ANDES will call `check_var()` of the discrete component
-        before initializing this variable.
+        Discrete component on which this variable depends. ANDES will call
+        `check_var()` of the discrete component before initializing this
+        variable.
+    name : str, optional
+        Variable name. One should typically assigning the name directly because
+        it will be automatically assigned by the model. The value of ``name``
+        will be the symbol name to be used in expressions.
 
     Attributes
     ----------
@@ -54,9 +55,8 @@ class BaseVar:
     v_str : str
         explicit initialization equation
     v_str_add : bool
-        True if the value of `v_str` will be added to the variable.
-        Useful when other models access this variable and set part
-        of the initial value
+        True if the value of `v_str` will be added to the variable. Useful when
+        other models access this variable and set part of the initial value
     v_iter : str
         implicit iterative equation in the form of 0 = v_iter
     """
@@ -90,7 +90,7 @@ class BaseVar:
 
         self.v_str = v_str    # equation string (v = v_str) for variable initialization
         self.v_iter = v_iter  # the implicit equation (0 = v_iter) for iterative initialization
-        self.e_str = e_str    # equation string
+        self.e_str = e_str    # residual equation string
 
         self.discrete = discrete
         self.v_setter = v_setter        # True if this variable sets the variable value
@@ -110,9 +110,6 @@ class BaseVar:
         # address into the variable and equation arrays (dae.f/dae.g and dae.x/dae.y)
         self.a: np.ndarray = np.array([], dtype=int)
 
-        # address into external equation RHS array (dae.h/dae.i)
-        self.r: np.ndarray = np.array([], dtype=int)
-
         self.av: np.ndarray = np.array([], dtype=int)      # FIXME: future var. address array
         self.ae: np.ndarray = np.array([], dtype=int)      # FIXME: future equation address array
         # --- attributes assigned by `set_address` ends ---
@@ -173,6 +170,7 @@ class BaseVar:
         contiguous : bool, optional
             If the addresses are contiguous
         """
+
         self.a = addr
         self.n = len(self.a)
 
@@ -200,6 +198,7 @@ class BaseVar:
         dae : DAE
             Reference to System.dae
         """
+
         if inplace is True:
             self._set_arrays_inplace(dae)
         if alloc is True:
@@ -241,7 +240,23 @@ class BaseVar:
 
 class Algeb(BaseVar):
     """
-    Algebraic variable class, an alias of the `BaseVar`.
+    Algebraic variable class, an alias of :py:class:`andes.core.var.BaseVar`.
+
+    Note that residual equations corresponding to algebraic variables are given
+    in an implicit form.
+
+    Examples
+    --------
+    When an algebraic variable ``y`` and the equation ``y = x + z`` shall be
+    defined, use
+
+    .. code-block:: python
+
+        e_str = 'x + z - y'
+
+    because it expresses the equation ``x + z - y = 0``. It is a common mistake
+    to use ``e_str = 'x + z'``, which will result in a singular Jacobian matrix
+    because ``d(x + z) / d(y)`` is zero.
 
     Attributes
     ----------
@@ -250,24 +265,26 @@ class Algeb(BaseVar):
     v_code : str
         Variable code string, equals string literal ``y``
     """
+
     e_code = 'g'
     v_code = 'y'
 
 
 class State(BaseVar):
-    """
+    r"""
     Differential variable class, an alias of the `BaseVar`.
 
     Parameters
     ----------
     t_const : BaseParam, DummyValue
-        Left-hand time constant for the differential equation.
-        Time constants will not be evaluated as part of the differential equation.
-        They will be collected to array `dae.Tf` to multiply to the right-hand side `dae.f`.
+        Left-hand time constant for the differential equation. They will be
+        collected to array ``dae.Tf``. Time constants will not be used when
+        evaluating the right-hand side specified in ``e_str`` but will be
+        applied to the left-hand side.
     check_init : bool
-        True to check if the equation right-hand-side is zero
-        initially. Disabling the checking can be used for integrators
-        when the initial input may not be zero.
+        True to check if the equation right-hand-side is zero initially.
+        Disabling the checking can be used for integrators when the initial
+        input may not be zero.
 
     Attributes
     ----------
@@ -275,7 +292,29 @@ class State(BaseVar):
         Equation code string, equals string literal ``f``
     v_code : str
         Variable code string, equals string literal ``x``
+
+    Examples
+    --------
+    To implement the swing equation
+
+    .. math::
+
+        M \dot {\omega} = \tau_m - \tau_e - D(\omega - 1)
+
+    Do the following in the ``__init__()`` of a model class:
+
+    .. code-block:: python
+
+        self.omega = State(e_str = 'tm - te - D * (omega - 1)',
+                           t_const = self.M,
+                           ...
+                           )
+
+    Note that ``self.M``, the inertia parameter is given through ``t_const`` and
+    is not part of ``e_str``.
+
     """
+
     e_code = 'f'
     v_code = 'x'
 
@@ -318,11 +357,12 @@ class State(BaseVar):
 
 class ExtVar(BaseVar):
     """
-    Externally defined algebraic variable
+    Algebraic variable that links to an external model.
 
-    This class is used to retrieve the addresses of externally-
-    defined variable. The `e` value of the `ExtVar` will be added
-    to the corresponding address in the DAE equation.
+    This class is used to retrieve the addresses of a variable defined in an
+    external model. An equation can be defined for the ``ExtVar``. The evaluated
+    value for the equation will be stored in the  ``ExtVar.e`` attribute and
+    added to the equations corresponding to the external variables.
 
     Parameters
     ----------
@@ -331,19 +371,22 @@ class ExtVar(BaseVar):
     src : str
         Source variable name
     indexer : BaseParam, BaseService
-        A parameter of the hosting model, used as indices into
-        the source model and variable. If is None, the source
-        variable address will be fully copied.
-    allow_none : bool
+        A parameter of the hosting model, used as indices into the source model
+        and variable. If is None, the source variable address will be fully
+        copied.
+    allow_none : bool, optional, default=False
         True to allow None in indexer
+    e_str : string, optional, default=None
+        Equation string, the evaluated value of which will be added to the source
+        residual equation
 
     Attributes
     ----------
     parent_model : Model
         The parent model providing the original parameter.
     uid : array-like
-        An array containing the absolute indices into the
-        parent_instance values.
+        An array containing the absolute indices into the parent_instance
+        values.
     e_code : str
         Equation code string; copied from the parent instance.
     v_code : str
@@ -384,9 +427,14 @@ class ExtVar(BaseVar):
                          export=export,
                          diag_eps=diag_eps,
                          )
-        self.ename = ename  # equation name corresponding to this variable
+
+        # equation name corresponding to this variable
+        self.ename = ename
         self.tex_ename = tex_ename if tex_ename else ename
 
+        # address into external equation RHS array (dae.h/dae.i)
+        self.r: np.ndarray = np.array([], dtype=int)
+
         self.model = model
         self.src = src
         self.indexer = indexer
@@ -435,8 +483,6 @@ class ExtVar(BaseVar):
         try:
             slice_idx = slice(self.r[0], self.r[-1] + 1)
         except IndexError as e:
-            print(self.owner.class_name)
-            print(self.name)
             raise e
 
         if isinstance(self, ExtState):
@@ -536,9 +582,13 @@ class ExtState(ExtVar):
 
     Warnings
     --------
-    ``ExtState`` is not allowed to set ``t_const``, as it will conflict with the
-    source ``State`` variable. In fact, one should not set ``e_str`` for ``ExtState``.
+    ``ExtState`` is not allowed to set ``t_const``, as it may conflict with the
+    source ``State`` variable.
+
+    Only in rare cases should one set ``e_str`` for ``ExtState``. The
+    ``t_const`` of the source State variable is used.
     """
+
     e_code = 'f'
     r_code = 'h'
     v_code = 'x'
@@ -549,6 +599,7 @@ class ExtAlgeb(ExtVar):
     """
     External algebraic variable type.
     """
+
     e_code = 'g'
     r_code = 'i'
     v_code = 'y'
