@@ -17,12 +17,12 @@ class ST2CUTData(PSSBaseData):
     def __init__(self):
         PSSBaseData.__init__(self)
         self.MODE = NumParam(info='Input signal 1', mandatory=True)
-        self.busr = NumParam(info='Remote bus 1')
+        self.busr = IdxParam(info='Remote bus 1')
         self.busf = IdxParam(info='BusFreq idx for signal 1 mode 2',
                              model='BusFreq', )
 
         self.MODE2 = NumParam(info='Input signal 2')
-        self.busr2 = NumParam(info='Remote bus 2')
+        self.busr2 = IdxParam(info='Remote bus 2')
         self.busf2 = IdxParam(info='BusFreq idx for signal 2 mode 2', model='BusFreq')
 
         self.K1 = NumParam(default=1, tex_name='K_1',
