@@ -28,7 +28,7 @@ from andes.models import file_classes
 from andes.models.group import GroupBase
 from andes.routines import all_routines
 from andes.shared import (NCPUS_PHYSICAL, Pool, Process, dilled_vars,
-                          jac_names, matrix, np, sparse, spmatrix)
+                          jac_names, matrix, np, sparse, spmatrix, numba)
 from andes.utils.misc import elapsed
 from andes.utils.paths import (andes_root, confirm_overwrite, get_config_path,
                                get_pycode_path)
@@ -707,6 +707,14 @@ class System:
         if not self.config.numba:
             return
 
+        try:
+            getattr(numba, '__version__')
+        except ImportError:
+            # numba not installed
+            logger.warning("numba is enabled but not installed. Please install numba manually.")
+            self.config.numba = 0
+            return False
+
         use_parallel = bool(self.config.numba_parallel)
         nopython = bool(self.config.numba_nopython)
 
@@ -717,6 +725,8 @@ class System:
                              nopython=nopython,
                              )
 
+        return True
+
     def precompile(self,
                    models: Union[OrderedDict, None] = None,
                    nomp: bool = False,
@@ -738,7 +748,10 @@ class System:
         self.config.numba = 1
 
         self.setup()
-        self._init_numba(models)
+        numba_ok = self._init_numba(models)
+
+        if not numba_ok:
+            return
 
         def _precompile_model(model: Model):
             model.precompile()
@@ -1756,7 +1769,7 @@ class System:
 
     def import_groups(self):
         """
-        Import all groups classes defined in ``devices/group.py``.
+        Import all groups classes defined in ``models/group.py``.
 
         Groups will be stored as instances with the name as class names.
         All groups will be stored to dictionary ``System.groups``.
@@ -1811,7 +1824,7 @@ class System:
         Import routines as defined in ``routines/__init__.py``.
 
         Routines will be stored as instances with the name as class names.
-        All groups will be stored to dictionary ``System.groups``.
+        All routines will be stored to dictionary ``System.routines``.
 
         Examples
         --------
