@@ -16,12 +16,14 @@ class TestSMIB(unittest.TestCase):
         """
         Test power flow for SMIB.
         """
-        ss = andes.run(andes.get_case("smib/SMIB.json"),
-                       default_config=True,
-                       no_output=True,
-                       )
+        ss = andes.run(
+            andes.get_case("smib/SMIB.json"),
+            default_config=True,
+            no_output=True,
+        )
         np.testing.assert_array_almost_equal(ss.Bus.v.v, [1.05, 1, 1.01699103])
-        np.testing.assert_array_almost_equal(ss.Bus.a.v, [3.04692663e-01, 1.43878247e-22, 1.77930079e-01])
+        np.testing.assert_array_almost_equal(
+            ss.Bus.a.v, [3.04692663e-01, 1.43878247e-22, 1.77930079e-01])
 
 
 class Test5Bus(unittest.TestCase):
@@ -30,10 +32,11 @@ class Test5Bus(unittest.TestCase):
     """
 
     def setUp(self) -> None:
-        self.ss = andes.main.load(get_case('5bus/pjm5bus.json'),
-                                  default_config=True,
-                                  no_output=True,
-                                  )
+        self.ss = andes.main.load(
+            get_case('5bus/pjm5bus.json'),
+            default_config=True,
+            no_output=True,
+        )
 
     def test_essential(self):
         """
@@ -97,12 +100,13 @@ class TestKundur2AreaEIG(unittest.TestCase):
         Test eigenvalue run for Kundur using xlsx data.
         """
         self.xlsx = get_case("kundur/kundur_full.xlsx")
-        self.ss = andes.run(self.xlsx,
-                            default_config=True,
-                            no_output=True,
-                            )
+        ss = andes.run(
+            self.xlsx,
+            default_config=True,
+            no_output=True,
+        )
 
-        self.ss.EIG.run()
+        ss.EIG.run()
 
 
 class TestKundur2AreaPSSE(unittest.TestCase):
@@ -113,9 +117,12 @@ class TestKundur2AreaPSSE(unittest.TestCase):
     def setUp(self) -> None:
         raw = get_case("kundur/kundur.raw")
         dyr = get_case("kundur/kundur_full.dyr")
-        self.ss_psse = andes.run(raw, addfile=dyr, default_config=True,
-                                 no_output=True,
-                                 )
+        self.ss_psse = andes.run(
+            raw,
+            addfile=dyr,
+            default_config=True,
+            no_output=True,
+        )
 
     def test_psse_tds_run_with_stats(self):
         self.ss_psse.config.save_stats = 1
@@ -141,20 +148,22 @@ class TestNPCCRAW(unittest.TestCase):
     """
 
     def test_npcc_raw(self):
-        andes.run(get_case('npcc/npcc.raw'),
-                  default_config=True,
-                  no_output=True,
-                  )
+        andes.run(
+            get_case('npcc/npcc.raw'),
+            default_config=True,
+            no_output=True,
+        )
 
     def test_npcc_raw_tds(self):
-        ss = andes.run(get_case('npcc/npcc.raw'),
-                       verbose=50,
-                       routine='tds',
-                       no_output=True,
-                       profile=True,
-                       tf=10,
-                       default_config=True,
-                       )
+        ss = andes.run(
+            get_case('npcc/npcc.raw'),
+            verbose=50,
+            routine='tds',
+            no_output=True,
+            profile=True,
+            tf=10,
+            default_config=True,
+        )
 
         ss.dae.print_array('f')
         ss.dae.print_array('g')
@@ -162,24 +171,27 @@ class TestNPCCRAW(unittest.TestCase):
         ss.dae.print_array('g', tol=1e-4)
 
     def test_npcc_raw_convert(self):
-        ss = andes.run(get_case('npcc/npcc.raw'),
-                       convert=True,
-                       default_config=True,
-                       )
+        ss = andes.run(
+            get_case('npcc/npcc.raw'),
+            convert=True,
+            default_config=True,
+        )
 
         os.remove(ss.files.dump)
         self.assertEqual(ss.exit_code, 0, "Exit code is not 0.")
 
     def test_npcc_raw2json_convert(self):
-        ss = andes.run(get_case('npcc/npcc.raw'),
-                       convert='json',
-                       default_config=True,
-                       )
+        ss = andes.run(
+            get_case('npcc/npcc.raw'),
+            convert='json',
+            default_config=True,
+        )
 
-        ss2 = andes.run('npcc.json',
-                        default_config=True,
-                        no_output=True,
-                        )
+        ss2 = andes.run(
+            'npcc.json',
+            default_config=True,
+            no_output=True,
+        )
 
         os.remove(ss.files.dump)
         self.assertEqual(ss2.exit_code, 0, "Exit code is not 0.")
@@ -187,9 +199,10 @@ class TestNPCCRAW(unittest.TestCase):
     def test_read_json_from_memory(self):
         fd = open(get_case('ieee14/ieee14_zip.json'), 'r')
 
-        ss = andes.main.System(default_config=True,
-                               no_output=True,
-                               )
+        ss = andes.main.System(
+            default_config=True,
+            no_output=True,
+        )
         andes.io.json.read(ss, fd)
         ss.setup()
         ss.PFlow.run()
@@ -200,9 +213,10 @@ class TestNPCCRAW(unittest.TestCase):
     def test_read_mpc_from_memory(self):
         fd = open(get_case('matpower/case14.m'), 'r')
 
-        ss = andes.main.System(default_config=True,
-                               no_output=True,
-                               )
+        ss = andes.main.System(
+            default_config=True,
+            no_output=True,
+        )
         andes.io.matpower.read(ss, fd)
         ss.setup()
         ss.PFlow.run()
@@ -214,9 +228,10 @@ class TestNPCCRAW(unittest.TestCase):
         fd_raw = open(get_case('npcc/npcc.raw'), 'r')
         fd_dyr = open(get_case('npcc/npcc_full.dyr'), 'r')
 
-        ss = andes.main.System(default_config=True,
-                               no_output=True,
-                               )
+        ss = andes.main.System(
+            default_config=True,
+            no_output=True,
+        )
         # suppress out-of-normal info
         ss.config.warn_limits = 0
         ss.config.warn_abnormal = 0
@@ -233,50 +248,69 @@ class TestNPCCRAW(unittest.TestCase):
 
 
 class TestPlot(unittest.TestCase):
+
     def test_kundur_plot(self):
-        ss = andes.run(get_case('kundur/kundur_full.json'),
-                       routine='tds',
-                       tf=2.0,
-                       no_output=True,
-                       default_config=True,
-                       )
+        import matplotlib
+        matplotlib.use('Agg')  # use headless plot for testing
+
+        ss = andes.run(
+            get_case('kundur/kundur_full.json'),
+            routine='tds',
+            tf=2.0,
+            no_output=True,
+            default_config=True,
+        )
 
         ss.TDS.load_plotter()
 
-        ss.TDS.plt.plot(ss.Bus.v, ylabel="Bus Voltages [pu]",
-                        title='Bus Voltage Plot',
-                        left=0.2, right=1.5,
-                        ymin=0.95, ymax=1.05, legend=True, grid=True, greyscale=True,
-                        hline=[1.01, 1.02], vline=[0.5, 0.8],
-                        dpi=80, line_width=1.2, font_size=11, show=False,
-                        )
+        ss.TDS.plt.plot(
+            ss.Bus.v,
+            ylabel="Bus Voltages [pu]",
+            title='Bus Voltage Plot',
+            left=0.2,
+            right=1.5,
+            ymin=0.95,
+            ymax=1.05,
+            legend=True,
+            grid=True,
+            greyscale=True,
+            hline=[1.01, 1.02],
+            vline=[0.5, 0.8],
+            dpi=80,
+            line_width=1.2,
+            font_size=11,
+            show=False,
+        )
 
         self.assertEqual(ss.exit_code, 0, "Exit code is not 0.")
 
 
 class TestCOI(unittest.TestCase):
+
     def test_kundur_COI(self):
         ss = get_case('kundur/kundur_coi.json')
-        exit_code = andes.run(ss,
-                              routine='tds',
-                              no_output=True,
-                              tf=0.1,
-                              cli=True,
-                              default_config=True,
-                              )
+        exit_code = andes.run(
+            ss,
+            routine='tds',
+            no_output=True,
+            tf=0.1,
+            cli=True,
+            default_config=True,
+        )
 
         self.assertEqual(exit_code, 0, "Exit code is not 0.")
 
     def test_kundur_COI_empty(self):
         ss = get_case('kundur/kundur_coi_empty.json')
 
-        exit_code = andes.run(ss,
-                              routine='tds',
-                              no_output=True,
-                              tf=0.1,
-                              cli=True,
-                              default_config=True,
-                              )
+        exit_code = andes.run(
+            ss,
+            routine='tds',
+            no_output=True,
+            tf=0.1,
+            cli=True,
+            default_config=True,
+        )
 
         self.assertEqual(exit_code, 0, "Exit code is not 0.")
 
@@ -288,12 +322,13 @@ class TestVSC(unittest.TestCase):
         """Test power flow exit code"""
 
         ss = get_case('kundur/kundur_vsc.json')
-        exit_code = andes.run(ss,
-                              routine='pflow',
-                              no_output=True,
-                              cli=True,
-                              default_config=True,
-                              )
+        exit_code = andes.run(
+            ss,
+            routine='pflow',
+            no_output=True,
+            cli=True,
+            default_config=True,
+        )
 
         self.assertEqual(exit_code, 0, "Exit code is not 0.")
 
@@ -307,10 +342,11 @@ class TestShuntSw(unittest.TestCase):
         """
 
         case = get_case('ieee14/ieee14_shuntsw.json')
-        ss = andes.run(case,
-                       no_output=True,
-                       default_config=True,
-                       )
+        ss = andes.run(
+            case,
+            no_output=True,
+            default_config=True,
+        )
 
         self.assertEqual(ss.exit_code, 0, "Exit code is not 0.")
 
@@ -326,7 +362,8 @@ class TestIslands(unittest.TestCase):
 
     def test_islands(self):
         ss = andes.run(get_case('kundur/kundur_islands.json'),
-                       no_output=True, default_config=True)
+                       no_output=True,
+                       default_config=True)
 
         self.assertEqual(ss.exit_code, 0, "Exit code is not 0.")
         self.assertEqual(len(ss.Bus.islands), 2)
@@ -341,10 +378,11 @@ class TestCaseInit(unittest.TestCase):
         """
         Test if PVD1 model initialization works.
         """
-        ss = andes.run(get_case('ieee14/ieee14_pvd1.json'),
-                       no_output=True,
-                       default_config=True,
-                       )
+        ss = andes.run(
+            get_case('ieee14/ieee14_pvd1.json'),
+            no_output=True,
+            default_config=True,
+        )
         ss.config.warn_limits = 0
         ss.config.warn_abnormal = 0
 
@@ -356,10 +394,11 @@ class TestCaseInit(unittest.TestCase):
         """
         Test EXAC1 initialization with one TGOV1 at lower limit.
         """
-        ss = andes.load(get_case('ieee14/ieee14_exac1.json'),
-                        no_output=True,
-                        default_config=True,
-                        )
+        ss = andes.load(
+            get_case('ieee14/ieee14_exac1.json'),
+            no_output=True,
+            default_config=True,
+        )
         ss.PV.config.pv2pq = 1
         ss.PFlow.run()
 
